==> qmmp_0.5.5.orig.tar.gz: qmmp-0.5.5/src/plugins/General/scrobbler/translations/scrobbler_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="30"/>
        <source>Scrobbler Plugin</source>
        <translation>Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="50"/>
        <source>About Scrobbler Plugin</source>
        <translation>關於 Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Qmmp Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Scrobbler 插件設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Session:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Register new session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>User name:</source>
        <translation>用戶名：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
</context>
</TS>

==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/General/scrobbler/translations/scrobbler_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="30"/>
        <source>Scrobbler Plugin</source>
        <translation>Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="50"/>
        <source>About Scrobbler Plugin</source>
        <translation>關於 Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Qmmp Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Scrobbler 插件設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Session:</source>
        <translation>會議：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Register new session</source>
        <translation>註冊新會議</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>User name:</source>
        <translation>用戶名：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
</context>
</TS>
